@@ -22,6 +22,7 @@ from werkzeug.security import gen_salt
 
 from drift.core.extensions.tenancy import current_tenant_name, split_host
 from drift.core.extensions.urlregistry import Endpoints
+from drift.fixers import CustomJSONEncoder
 from drift.utils import get_tier_name
 
 JWT_VERIFY_CLAIMS = ['signature', 'exp', 'iat']
@@ -258,9 +259,6 @@ def _authenticate(auth_info, conf):
 
     provider_details = auth_info.get('provider_details')
 
-    # TODO: Move specific auth logic outside this module.
-    # Steam and Game Center. should not be in here.
-
     # In fact only JWT is supported by all drift based deployables. Everything else
     # is specific to drift-base.
     if auth_info['provider'] == "jwt":
@@ -298,19 +296,20 @@ class AuthRequestSchema(ma.Schema):
     class Meta:
         strict = True
 
-    provider = ma.fields.Str(description="Provider name")
-    provider_details = ma.fields.Dict(description="Provider specific details")
-    username = ma.fields.Str(description="Legacy username")
-    password = ma.fields.Str(description="Legacy password")
-    automatic_account_creation = ma.fields.Boolean(description="Automatically create new users", default=True)
+    provider = ma.fields.Str(metadata=dict(description="Provider name"))
+    provider_details = ma.fields.Dict(metadata=dict(description="Provider specific details"))
+    username = ma.fields.Str(metadata=dict(description="Legacy username"))
+    password = ma.fields.Str(metadata=dict(description="Legacy password"))
+    automatic_account_creation = ma.fields.Boolean(missing=True,
+                                                   metadata=dict(description="Automatically create new users"))
 
 
 class AuthSchema(ma.Schema):
     class Meta:
         strict = True
 
-    token = ma.fields.String(description="Token")
-    jti = ma.fields.String(description="Token id")
+    token = ma.fields.String(metadata=dict(description="Token"))
+    jti = ma.fields.String(metadata=dict(description="Token id"))
 
 
 @bp.route('', endpoint='authentication')
@@ -422,7 +421,7 @@ def issue_token(payload, expire=None):
     cache_token(payload, expire=expire)
     log.debug("Issuing a new token: %s.", payload)
     ret = {
-        'token': access_token.decode('utf-8'),
+        'token': access_token,
         'payload': payload,
     }
     return ret
@@ -610,7 +609,7 @@ def cache_token(payload, expire=None):
         jti = payload['jti']
         key = "jwt:{}".format(jti)
         if hasattr(g, 'redis'):
-            g.redis.set(key, json.dumps(payload), expire=expire)
+            g.redis.set(key, json.dumps(payload, cls=CustomJSONEncoder), expire=expire)
             log.debug("Token cached in redis for %s seconds: %s", expire, key)
     except Exception:
         log.exception("Exception putting jwt '%s' into redis", jti)
@@ -658,11 +657,11 @@ class JwkSchema(ma.Schema):
     class Meta:
         strict = True
 
-    kty = ma.fields.String(description="Key Type")
-    use = ma.fields.String(description="Public Key Use")
-    alg = ma.fields.String(description="Algorithm")
-    n = ma.fields.String(description="Public Modulus")
-    e = ma.fields.String(description="Public Exponent")
+    kty = ma.fields.String(metadata=dict(description="Key Type"))
+    use = ma.fields.String(metadata=dict(description="Public Key Use"))
+    alg = ma.fields.String(metadata=dict(description="Algorithm"))
+    n = ma.fields.String(metadata=dict(description="Public Modulus"))
+    e = ma.fields.String(metadata=dict(description="Public Exponent"))
 
 
 class JwksSchema(ma.Schema):
